/*
 *  The Mana World
 *  Copyright 2006 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "animationparticle.h"

#include "graphics.h"
#include "simpleanimation.h"

AnimationParticle::AnimationParticle(Map *map, Animation *animation):
    ImageParticle(map, NULL),
    mAnimation(new SimpleAnimation(animation))
{
}

AnimationParticle::AnimationParticle(Map *map, xmlNodePtr animationNode):
    ImageParticle(map, 0),
    mAnimation(new SimpleAnimation(animationNode))
{
}

AnimationParticle::~AnimationParticle()
{
    delete mAnimation;
    mImage = NULL;
}

bool AnimationParticle::update()
{
    mAnimation->update(10); // particle engine is updated every 10ms
    mImage = mAnimation->getCurrentImage();

    return Particle::update();
}
